%define major 13
%define libname %mklibname exiv2_ %{major}
%define libdev %mklibname exiv2 -d

Summary:	Command line tool to access EXIF data in image files
Name:		exiv2
Version:	0.24
%define subrel	1
Release:	%mkrel 5
License:	GPLv2+
Group:		Graphics/Utilities
Url:		http://www.exiv2.org/
Source:		http://www.exiv2.org/%{name}-%{version}.tar.gz
Patch0:		exiv2-0.24-CVE-2014-9449.patch
Patch1:		exiv2-0.24-parallel-build.patch
BuildRequires:	doxygen
BuildRequires:	graphviz
BuildRequires:	python
BuildRequires:	libxslt-proc
BuildRequires:	expat-devel
BuildRequires:	zlib-devel

%description
Exiv2 is a command line utility to access image metadata:
* print the Exif metadata of JPEG, TIFF and several RAW image formats as
  summary info, interpreted values, or the plain data for each tag
* print the IPTC metadata of JPEG images
* print, set and delete the JPEG comment of JPEG images
* set, add and delete Exif and IPTC metadata of JPEG images
* adjust the Exif timestamp (that's how it all started...)
* rename Exif image files according to the Exif timestamp
* extract, insert and delete Exif metadata, IPTC metadata and JPEG comments
* extract, insert and delete the thumbnail image embedded in the Exif metadata
* fix the Exif ISO setting of picture taken with Nikon cameras

%package -n	%{libname}
Summary:	Library to access EXIF data in image files
Group:		Graphics/Utilities
Obsoletes:	%{_lib}exiv22 < 0.16-1
 
%description -n	%{libname}
libexiv2 is a C++ library to access image metadata. libexiv2 is free
software.

The Exiv2 library provides:
* full read and write access to the Exif and IPTC metadata of
  an image through Exiv2 keys and standard C++ iterators
* a smart IPTC implementation that does not affect data that
  programs like Photoshop store in the same image segment
* Exif MakerNote support:
      o MakerNote tags can be accessed just like any other Exif metadata
      o a sophisticated write algorithm avoids corrupting the MakerNote:
          1) the MakerNote is not re-located if possible at all, and
          2) MakerNote Ifd offsets are re-calculated if the MakerNote 
             needs to be moved (for known Ifd MakerNotes)
* extract and delete methods for Exif thumbnails (both, JPEG and TIFF
  thumbnails)
* set methods for Exif thumbnails (JPEG only, TIFF thumbnails can be
  set from individual tags)
* complete API documentation (by Doxygen)

%package -n	%{libdev}
Summary: 	Headers and links to compile against the "%{libname}" library
Requires: 	%{libname} = %{version}
Requires:       multiarch-utils
Provides:	libexiv-devel = %{version}
Group:		Development/C

%description -n	%{libdev}
This package contains all files which one needs to compile programs using
the "%{libname}" library.

%package	doc
Summary:	Exiv2 library documentation
Group:		Documentation
BuildArch:	noarch

%description	doc
Exiv2 library documentation.

%prep
%setup -q -n %{name}-%{version}
%patch0 -p0 -b .CVE-2014-9449
%patch1 -p1 -b .parallel

%build
# exiv2: embedded copy of exempi should be compiled with BanAllEntityUsage
# https://bugzilla.redhat.com/show_bug.cgi?id=888769
export CPPFLAGS="-DBanAllEntityUsage=1"

%configure2_5x --enable-shared --disable-static
%make
%make update-po -C po
%make doc -k ||:

%install
%makeinstall_std

%find_lang exiv2

rm -f %{buildroot}%{_libdir}/*.la

%files  -f %{name}.lang
%doc COPYING README
%{_bindir}/%{name}
%{_mandir}/man1/*

%files -n %{libname}
%{_libdir}/lib%{name}.so.%{major}*

%files -n %{libdev}
%{_libdir}/lib%{name}.so
%{_libdir}/pkgconfig/*
%{_includedir}/*

%files doc
%doc doc/ChangeLog doc/cmd.txt doc/html doc/include doc/index.html doc/templates


%changelog
* Fri Mar 04 2016 luigiwalser <luigiwalser> 0.24-5.1.mga5
+ Revision: 985701
- embedded copy of exempi should be compiled with BanAllEntityUsage (rhbz#888769)

* Fri Feb 27 2015 pterjan <pterjan> 0.24-5.mga5
+ Revision: 817139
- Add opensuse patch fixing parallel build

* Thu Jan 08 2015 luigiwalser <luigiwalser> 0.24-4.mga5
+ Revision: 809356
- add upstream patch to fix CVE-2014-9449

* Wed Oct 15 2014 umeabot <umeabot> 0.24-3.mga5
+ Revision: 742701
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.24-2.mga5
+ Revision: 679062
- Mageia 5 Mass Rebuild

* Mon Feb 10 2014 dams <dams> 0.24-1.mga5
+ Revision: 588947
- new version 0.24
- update %%major
- clean specfile

* Fri Oct 18 2013 umeabot <umeabot> 0.23-4.mga4
+ Revision: 504210
- Mageia 4 Mass Rebuild

* Fri Jan 11 2013 umeabot <umeabot> 0.23-3.mga3
+ Revision: 349867
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

  + boklm <boklm>
    - Update group: Graphics/Other -> Graphics/Utilities

* Fri Nov 09 2012 fwang <fwang> 0.23-2.mga3
+ Revision: 316594
- update rpm group
- update rpm group
- update rpm group

* Mon Jun 18 2012 fwang <fwang> 0.23-1.mga3
+ Revision: 261591
- update libmajor
- new version 0.23

* Sun Oct 09 2011 fwang <fwang> 0.22-1.mga2
+ Revision: 153403
- update libmajor
- new version 0.22

* Wed Apr 20 2011 pterjan <pterjan> 0.21.1-1.mga1
+ Revision: 89207
- Update to 0.21.1

* Fri Jan 14 2011 mikala <mikala> 0.21-1.mga1
+ Revision: 18068
- Drop mdk macros
- Remove BuildRoot
- imported package exiv2

